"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.TreeView = void 0;
var _react = _interopRequireDefault(require("react"));
var _reactNative = require("react-native");
var _NodeList = _interopRequireDefault(require("./components/NodeList"));
var _helpers = require("./helpers");
var _treeView = require("./store/treeView.store");
var _usePreviousState = _interopRequireDefault(require("./utils/usePreviousState"));
var _shallow = require("zustand/react/shallow");
var _jsxRuntime = require("react/jsx-runtime");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
const _TreeView = /*#__PURE__*/_react.default.forwardRef((props, ref) => {
  const {
    data,
    onCheck,
    onExpand,
    selectionPropagation,
    preselectedIds = [],
    preExpandedIds = [],
    treeFlashListProps,
    checkBoxViewStyleProps,
    indentationMultiplier,
    CheckboxComponent,
    ExpandCollapseIconComponent,
    ExpandCollapseTouchableComponent,
    CustomNodeRowComponent
  } = props;
  const {
    expanded,
    updateExpanded,
    initialTreeViewData,
    updateInitialTreeViewData,
    searchText,
    updateSearchText,
    updateSearchKeys,
    checked,
    indeterminate,
    setSelectionPropagation,
    cleanUpTreeViewStore
  } = (0, _treeView.useTreeViewStore)((0, _shallow.useShallow)(state => ({
    expanded: state.expanded,
    updateExpanded: state.updateExpanded,
    initialTreeViewData: state.initialTreeViewData,
    updateInitialTreeViewData: state.updateInitialTreeViewData,
    searchText: state.searchText,
    updateSearchText: state.updateSearchText,
    updateSearchKeys: state.updateSearchKeys,
    checked: state.checked,
    indeterminate: state.indeterminate,
    setSelectionPropagation: state.setSelectionPropagation,
    cleanUpTreeViewStore: state.cleanUpTreeViewStore
  })));
  _react.default.useImperativeHandle(ref, () => ({
    selectAll: _helpers.selectAll,
    unselectAll: _helpers.unselectAll,
    selectAllFiltered: _helpers.selectAllFiltered,
    unselectAllFiltered: _helpers.unselectAllFiltered,
    expandAll: _helpers.expandAll,
    collapseAll: _helpers.collapseAll,
    expandNodes: _helpers.expandNodes,
    collapseNodes: _helpers.collapseNodes,
    selectNodes,
    unselectNodes,
    setSearchText
  }));
  const prevSearchText = (0, _usePreviousState.default)(searchText);
  _react.default.useEffect(() => {
    updateInitialTreeViewData(data);
    if (selectionPropagation) setSelectionPropagation(selectionPropagation);
    (0, _helpers.initializeNodeMaps)(data);

    // Check any pre-selected nodes
    (0, _helpers.toggleCheckboxes)(preselectedIds, true);

    // Expand pre-expanded nodes
    (0, _helpers.expandNodes)(preExpandedIds);
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);
  function selectNodes(ids) {
    (0, _helpers.toggleCheckboxes)(ids, true);
  }
  function unselectNodes(ids) {
    (0, _helpers.toggleCheckboxes)(ids, false);
  }
  function setSearchText(text, keys = ["name"]) {
    updateSearchText(text);
    updateSearchKeys(keys);
  }
  const getIds = _react.default.useCallback(node => {
    if (!node.children || node.children.length === 0) {
      return [node.id];
    } else {
      return [node.id, ...node.children.flatMap(item => getIds(item))];
    }
  }, []);
  _react.default.useEffect(() => {
    onCheck?.(Array.from(checked), Array.from(indeterminate));
  }, [onCheck, checked, indeterminate]);
  _react.default.useEffect(() => {
    onExpand?.(Array.from(expanded));
  }, [onExpand, expanded]);
  _react.default.useEffect(() => {
    if (searchText) {
      _reactNative.InteractionManager.runAfterInteractions(() => {
        updateExpanded(new Set(initialTreeViewData.flatMap(item => getIds(item))));
      });
    } else if (prevSearchText && prevSearchText !== "") {
      /* Collapse all nodes only if previous search query was non-empty: this is 
      done to prevent node collapse on first render if preExpandedIds is provided */
      _reactNative.InteractionManager.runAfterInteractions(() => {
        updateExpanded(new Set());
      });
    }
  }, [getIds, initialTreeViewData, prevSearchText, searchText, updateExpanded]);
  _react.default.useEffect(() => {
    return () => {
      cleanUpTreeViewStore();
    };
  }, [cleanUpTreeViewStore]);
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_NodeList.default, {
    treeFlashListProps: treeFlashListProps,
    checkBoxViewStyleProps: checkBoxViewStyleProps,
    indentationMultiplier: indentationMultiplier,
    CheckboxComponent: CheckboxComponent,
    ExpandCollapseIconComponent: ExpandCollapseIconComponent,
    ExpandCollapseTouchableComponent: ExpandCollapseTouchableComponent,
    CustomNodeRowComponent: CustomNodeRowComponent
  });
});
const TreeView = exports.TreeView = /*#__PURE__*/_react.default.memo(_TreeView);
//# sourceMappingURL=TreeView.js.map